@@ -3,6 +3,10 @@
 
 #include <clutter-gtk/clutter-gtk.h>
 
+#ifndef EXAMPLES_DATADIR
+#define EXAMPLES_DATADIR "."
+#endif
+
 typedef struct {
 
   GtkWidget    *window;
@@ -42,31 +46,22 @@ on_gtk_entry_changed (GtkEditable *editable, EventApp *app)
 static void
 on_x_changed (GtkSpinButton *button, EventApp *app)
 {
-  clutter_actor_set_rotation (app->hand, CLUTTER_X_AXIS,
-                              gtk_spin_button_get_value (button),
-                              0,
-                              clutter_actor_get_height (app->hand) / 2,
-                              0);
+  clutter_actor_set_rotation_angle (app->hand, CLUTTER_X_AXIS,
+                                    gtk_spin_button_get_value (button));
 }
 
 static void
 on_y_changed (GtkSpinButton *button, EventApp *app)
 {
-  clutter_actor_set_rotation (app->hand, CLUTTER_Y_AXIS,
-                              gtk_spin_button_get_value (button),
-                              clutter_actor_get_width (app->hand) / 2,
-                              0,
-                              0);
+  clutter_actor_set_rotation_angle (app->hand, CLUTTER_Y_AXIS,
+                                    gtk_spin_button_get_value (button));
 }
 
 static void
 on_z_changed (GtkSpinButton *button, EventApp *app)
 {
-  clutter_actor_set_rotation (app->hand, CLUTTER_Z_AXIS,
-                              gtk_spin_button_get_value (button),
-                              clutter_actor_get_width (app->hand) / 2,
-                              clutter_actor_get_height (app->hand) / 2,
-                              0);
+  clutter_actor_set_rotation_angle (app->hand, CLUTTER_Z_AXIS,
+                                    gtk_spin_button_get_value (button));
 }
 
 static void
@@ -75,14 +70,6 @@ on_opacity_changed (GtkSpinButton *button, EventApp *app)
   clutter_actor_set_opacity (app->hand, gtk_spin_button_get_value (button)); 
 }
 
-/* Set the clutter colors form the current gtk theme */
-static void
-create_colors (EventApp *app, ClutterColor *stage, ClutterColor *text)
-{
-  gtk_clutter_get_bg_color (app->window, GTK_STATE_NORMAL, stage);
-  gtk_clutter_get_text_color (app->window, GTK_STATE_NORMAL, text);
-}
-
 static gboolean
 on_stage_capture (ClutterActor *stage,
                   ClutterEvent *event,
@@ -154,8 +141,7 @@ main (gint argc, gchar **argv)
   GtkWidget     *widget, *vbox, *hbox, *button, *label, *box;
   ClutterActor  *actor;
   GdkPixbuf     *pixbuf = NULL;
-  ClutterColor   stage_color = {255, 255, 255, 255};
-  ClutterColor   text_color = {0, 0, 0, 255};
+  GtkSizeGroup  *size_group;
 
   if (gtk_clutter_init_with_args (&argc, &argv, "- Event test", NULL, NULL, NULL) != CLUTTER_INIT_SUCCESS)
     g_error ("Unable to initialize GtkClutter");
@@ -170,7 +156,7 @@ main (gint argc, gchar **argv)
   g_signal_connect (widget, "destroy", G_CALLBACK (gtk_main_quit), NULL);
  
   /* Create our layout box */
-  vbox = gtk_vbox_new (FALSE, 12);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
   gtk_container_add (GTK_CONTAINER (app->window), vbox);
 
   widget = gtk_entry_new ();
@@ -179,16 +165,14 @@ main (gint argc, gchar **argv)
   gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
   g_signal_connect (widget, "changed", G_CALLBACK (on_gtk_entry_changed), app);
 
-  hbox = gtk_hbox_new (FALSE, 12);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
   
   /* Set up clutter & create our stage */
-  create_colors (app, &stage_color, &text_color);
   widget = gtk_clutter_embed_new ();
   gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
   gtk_widget_grab_focus (widget);
   app->stage = gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (widget));
-  clutter_stage_set_color (CLUTTER_STAGE (app->stage), &stage_color);
   gtk_widget_set_size_request (widget, 640, 480);
   g_signal_connect (app->stage, "captured-event",
                     G_CALLBACK (on_stage_capture),
@@ -201,17 +185,15 @@ main (gint argc, gchar **argv)
                     NULL);
 
   /* Create the main texture that the spin buttons manipulate */
-  pixbuf = gdk_pixbuf_new_from_file ("redhand.png", NULL);
+  pixbuf = gdk_pixbuf_new_from_file (EXAMPLES_DATADIR G_DIR_SEPARATOR_S "redhand.png", NULL);
   if (pixbuf == NULL)
     g_error ("Unable to load pixbuf\n");
 
   app->hand = actor = gtk_clutter_texture_new ();
   gtk_clutter_texture_set_from_pixbuf (GTK_CLUTTER_TEXTURE (actor), pixbuf, NULL);
-  clutter_container_add_actor (CLUTTER_CONTAINER (app->stage), actor);
-  clutter_actor_set_anchor_point_from_gravity (actor, CLUTTER_GRAVITY_CENTER);
-  clutter_actor_set_position (actor,
-                              clutter_actor_get_width (app->stage) / 2,
-                              clutter_actor_get_height (app->stage) / 2);
+  clutter_actor_add_child (app->stage, actor);
+  clutter_actor_set_pivot_point (actor, 0.5, 0.5);
+  clutter_actor_add_constraint (actor, clutter_align_constraint_new (app->stage, CLUTTER_ALIGN_BOTH, 0.5));
   clutter_actor_set_reactive (actor, TRUE);
   clutter_actor_set_name (actor, "Red Hand");
   g_signal_connect (actor, "button-press-event",
@@ -219,44 +201,49 @@ main (gint argc, gchar **argv)
                     NULL);
 
   /* Setup the clutter entry */
-  actor = clutter_text_new_full ("Sans 10", "", &text_color);
+  actor = clutter_text_new_full (NULL, "", CLUTTER_COLOR_Black);
   app->clutter_entry = actor;
-  clutter_group_add (CLUTTER_GROUP (app->stage), actor);
+  clutter_actor_add_child (app->stage, actor);
   clutter_actor_set_position (actor, 0, 0);
   clutter_actor_set_size (actor, 500, 20);
 
   /* Create our adjustment widgets */
-  vbox = gtk_vbox_new (FALSE, 6);
+  size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 
-  box = gtk_hbox_new (TRUE, 6);
+  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, TRUE, 0);
   label = gtk_label_new ("Rotate x-axis");
+  gtk_size_group_add_widget (size_group, label);
   gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
   button = gtk_spin_button_new_with_range (0, 360, 1);
   gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
   g_signal_connect (button, "value-changed", G_CALLBACK (on_x_changed), app);
   
-  box = gtk_hbox_new (TRUE, 6);
+  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, TRUE, 0);
   label = gtk_label_new ("Rotate y-axis");
   gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
+  gtk_size_group_add_widget (size_group, label);
   button = gtk_spin_button_new_with_range (0, 360, 1);
   gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
   g_signal_connect (button, "value-changed", G_CALLBACK (on_y_changed), app);
 
-  box = gtk_hbox_new (TRUE, 6);
+  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, TRUE, 0);
   label = gtk_label_new ("Rotate z-axis");
   gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
+  gtk_size_group_add_widget (size_group, label);
   button = gtk_spin_button_new_with_range (0, 360, 1);
   gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
   g_signal_connect (button, "value-changed", G_CALLBACK (on_z_changed), app);
 
-  box = gtk_hbox_new (TRUE, 6);
+  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, TRUE, 0);
   label = gtk_label_new ("Adjust opacity");
   gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
+  gtk_size_group_add_widget (size_group, label);
   button = gtk_spin_button_new_with_range (0, 255, 1);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), 255);
   gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
@@ -267,7 +254,7 @@ main (gint argc, gchar **argv)
   /* Only show/show_all the stage after parent show. widget_show will call
    * show on the stage.
   */
-  clutter_actor_show_all (app->stage);
+  clutter_actor_show (app->stage);
 
   gtk_main ();
   
